<?php
/**
 * This is where we put all the admin functions for the plugin
 * to the content editor within the admin
 *
 * @category 			Plugins
 * @package  			MediaBlender
 * @author   			Metaphor Creations
 * @license: 			ThemeForest Licensing Terms
 * @license uri:	http://20script.ir
 * @link     			http://plugins.metaphorcreations.com/mediablender
 **/
 
 
 
 
add_action( 'admin_enqueue_scripts', 'mediablender_admin_scripts' );
/**
 * Add the necessary scripts to the admin.
 *
 * @since 1.1
 */
function mediablender_admin_scripts( $hook_suffix ) {
	
	// Add the stylesheet
	wp_enqueue_style( 'mediablender', MEDIABLENDER_URL.'/css/mediablender.css', false, MEDIABLENDER_VERSION );
	wp_enqueue_style( 'mediablender-admin', MEDIABLENDER_URL.'/css/mediablender-admin.css', false, MEDIABLENDER_VERSION );
	
	// Add the jQuery cookie script
	wp_register_script( 'jquery-cookie', MEDIABLENDER_URL.'/js/jquery.cookie.js', array( 'jquery' ), METATOOLS_VERSION, true );
	wp_enqueue_script( 'jquery-cookie' );
	
	// Add jQuery easing
	wp_register_script( 'jquery-easing', MEDIABLENDER_URL.'/js/jquery.easing.js', array('jquery'), MEDIABLENDER_VERSION, true );
	wp_enqueue_script( 'jquery-easing' );
	
	// Add the jQuery
	wp_register_script( 'mediablender', MEDIABLENDER_URL.'/js/mediablender.js', array('jquery', 'jquery-cookie'), MEDIABLENDER_VERSION, true );
	wp_enqueue_script( 'mediablender' );
	
	// Create navigation settings
	$nav_settings = array(
		'nav_before' => '',
		'nav_after'  => '',
		'nav_link_before' => '',
		'nav_link_after'  => '',
	);
	$nav_settings = apply_filters( 'mediablender_admin_nav_settings', $nav_settings );
	
	wp_localize_script( 'mediablender', 'mediablender_vars', array(
			'cookie_hash' => COOKIEHASH,
			'comment_text' => __('Comments', 'm4c'),
			'comment_single' => __('Comment', 'm4c'),
			'nav_settings' => $nav_settings
		)
	);
	
	// Add the popup div only on index.php (quick post), post.php or post-new.php pages
	if( $hook_suffix == 'index.php' || $hook_suffix == 'post.php' || $hook_suffix == 'post-new.php' ) {
		add_action( 'admin_footer', 'mediablender_gallery_chooser', 11 );
	}
	
	// Setup the media blender class for the edit columns
	if( $hook_suffix == 'edit.php' ) {
		if( isset($_GET['post_type']) ) {
			if( $_GET['post_type'] == 'mediablender' ) {
				add_action( 'admin_footer', 'mediablender_preview_link', 11 );
			}
		}
	}
	
	// Setup the media blender class for the dashboard widget
	if( $hook_suffix == 'index.php' ) {
		add_action( 'admin_footer', 'mediablender_preview_link', 11 );
	}
}




add_action( 'init','mediablender_posttype' );
/**
 * Creates the Media Blender post type.
 *
 * @since 1.0
 */
function mediablender_posttype() {
	
	// Create labels
	$labels = array(
		'name' => __('MediaBlender Galleries', 'm4c'),
		'singular_name' => __('Gallery', 'm4c'),
		'add_new' => __('Add New', 'm4c'),
		'add_new_item' => __('Add New', 'm4c'),
		'edit_item' => __('Edit Gallery', 'm4c'),
		'new_item' => __('New Gallery', 'm4c'),
		'view_item' => __('View Gallery', 'm4c'),
		'search_items' => __('Search Galleries', 'm4c'),
		'not_found' => __('No Galleries Found', 'm4c'),
		'not_found_in_trash' => __('No Galleries Found In Trash', 'm4c'), 
		'parent_item_colon' => '',
		'menu_name' => __('MediaBlender', 'm4c')
	);

	// Create the arguments
	$args = array(
		'labels' => $labels,
		'public' => false,
		'publicly_queryable' => true,
		'exclude_from_search' => true,
		'show_in_nav_menus' => true,
		'show_ui' => true, 
		'show_in_menu' => true, 
		'query_var' => true,
		'rewrite' => true,
		'supports' => array( 'title' )
	); 
	
	// Register the post type
	register_post_type( 'mediablender', $args );
}




/**
 * Create a gallery data metabox.
 *
 * @since 1.0
 */
$mediablender_gallery_data = array(
	'id' => 'mediablender_gallery_data',
	'title' => __('Gallery Data', 'm4c'),
	'page' => array( 'mediablender' ),
	'context' => 'normal',
	'priority' => 'high',
	'fields' => array(
		array(
			'id' => '_mediablender_attachments',
			'type' => 'gallery',
			'name' => __('Attachments', 'm4c'),
			'description' => __('Add attachments for the gallery.', 'm4c'),
			'button' => __('Add Attachments', 'm4c')
		),
		array(
			'id' => '_mediablender_description',
			'type' => 'textarea',
			'name' => __('Description', 'm4c'),
			'description' => __('Add a description for the gallery.', 'm4c'),
			'cols' => '80',
			'rows' => '8'
		)
	)
);
new MediaBlender_MetaBoxer( $mediablender_gallery_data );




add_action( 'wp_dashboard_setup', 'mediablender_add_dashboard_widget' );
/**
 * Add a custom dashboard widget to show galleries
 *
 * @since 1.0
 */
function mediablender_add_dashboard_widget() {
	wp_add_dashboard_widget( 'mediablender_dashboard_widget', __('MediaBlender Galleries', 'm4c'), 'mediablender_dashboard_widget_display');	
}




/**
 * Loop through all the galleries and add a thumbnail link.
 *
 * @since 1.0
 */
function mediablender_dashboard_widget_display() {
	
	$args = array(
		'post_type' => 'mediablender',
		'posts_per_page' => -1
	);
	$galleries = get_posts( $args );
	
	if( is_array($galleries) ) {
	
		echo '<div id="mediablener-dashboard-thumbs" class="clearfix">';
		if( is_array($galleries) ) {
			foreach( $galleries as $gallery ) {
				echo '<div class="mediablender-dashboard-gallery">';
				$id = $gallery->ID;
				$atts = get_post_meta( $id, '_mediablender_attachments', true );
				if( is_array($atts) ) {
					foreach( $atts as $i => $att ) {
						if( $i == 0 ) {
							$img = get_m4c_attachment_image( $atts[0], 'mediablender-column-image' );
							echo '<a href="#" id="'.$att.'" class="mediablender-gallery-preview" rel="'.$id.'">'.$img.'<span class="mediablender-preview-icon"><span></a>';
						} else {
							echo '<a href="#" id="'.$att.'" class="mediablender-gallery-preview" style="display:none;" rel="'.$id.'"></a>';
						}
					}
				}
				echo '</div>';
			}
		}
		echo '</div>';
	}
} 




add_action( 'media_buttons', 'mediablender_media_button', 11 );
/**
 * Create a custom media button for MediaBlender shortcodes
 *
 * @since 1.1
 */
function mediablender_media_button(){
	echo '<a href="#TB_inline?width=720&amp;height=780&amp;inlineId=mediablender_gallery_chooser" class="thickbox" id="add_mediablender" title="'.__('Add MediaBlender Gallery', 'm4c').'"><img src="'.MEDIABLENDER_IMAGES_URL.'/mediablender-icon-14.png" alt="'.__('Add MediaBlender Gallery', 'm4c').'"></a>';
}




/**
 * Create the thickbox content to select a specific
 * MediaBlender gallery.
 *
 * @since 1.1
 */
function mediablender_gallery_chooser() {
	?>
	<script>
		jQuery( document ).ready( function() {
			jQuery( '.gallery-type' ).change( function() {
				jQuery( '.gallery-type' ).removeAttr( 'checked' );
				jQuery( this ).attr( 'checked', 'checked' );
				jQuery( '.gallery-option:not(.'+jQuery(this).val()+'-option)' ).hide();
				jQuery( '.'+jQuery(this).val()+'-option' ).show();
			});
			jQuery( '.data-position' ).change( function() {
				jQuery( '.data-position' ).removeAttr( 'checked' );
				jQuery( this ).attr( 'checked', 'checked' );
			});
			jQuery( '.navigation-position' ).change( function() {
				jQuery( '.navigation-position' ).removeAttr( 'checked' );
				jQuery( this ).attr( 'checked', 'checked' );
			});
		});
	
	  function mediablender_insert_gallery(){
	    var gallery_id = jQuery('#add_gallery_id').val();
	    if(gallery_id == ''){
        alert('Please select a gallery!');
        return;
	    }
	
	    var gallery_name = jQuery('#add_gallery_id option[value="'+gallery_id+'"]').text().replace(/[\[\]]/g, '');
	    var gallery_type = jQuery('.gallery-type[checked="checked"]').val();
	    var data_position = jQuery('.data-position[checked="checked"]').val();
	    var nav_position = jQuery('.navigation-position[checked="checked"]').val();
	    
	    var thumb_columns = jQuery('#thumb_columns').val();
	    
	    var attachment_spacing = jQuery('#attachment_spacing').val();
	    if( attachment_spacing == '' ) {
		    attachment_spacing = 10;
	    }
	    
	    var thumb_width = jQuery('#thumb_width').val();
	    var thumb_height = jQuery('#thumb_height').val();
	    
	    var gallery_width = jQuery('#gallery_width').val();
	    var gallery_height = jQuery('#gallery_height').val();
	    
	    var gallery_timer = jQuery('#gallery_timer').is(':checked');
	    var gallery_timer_speed = jQuery('#gallery_timer_speed').val();

	    
	    var display_gallery_title = jQuery('#display_gallery_title').is(':checked');
	    var display_gallery_description = jQuery('#display_gallery_description').is(':checked');
	    var display_attachment_titles = jQuery('#display_attachment_titles').is(':checked');
	    var display_attachment_descriptions = jQuery('#display_attachment_descriptions').is(':checked');
	    var attachment_comments = jQuery('#attachment_comments').is(':checked');
	    
	    
	    var mb_gallery_title = !display_gallery_title ? ' title="false"' : '';
	    var mb_gallery_description = !display_gallery_description ? ' description="false"' : '';
	    var mb_attachment_titles = !display_attachment_titles ? ' att_titles="false"' : '';
	    var mb_attachment_descriptions = !display_attachment_descriptions ? ' att_descriptions="false"' : '';
	    var mb_attachment_comments = !attachment_comments ? ' att_comments="false"' : '';  
	    
	    var mb_thumb_columns = '';
	    var mb_attachment_spacing = '';
	    var mb_gallery_width = '';
	    var mb_gallery_height = '';
	    var mb_thumb_width = '';
	    var mb_thumb_height = '';
	    var mb_gallery_timer = '';
	    var mb_gallery_timer_speed = '';
	    console.log(jQuery('.gallery-type[checked="checked"]').val());
	    switch ( jQuery('.gallery-type[checked="checked"]').val() ) {
		    case 'lightbox':
		    	mb_thumb_columns = ( thumb_columns ) ? ' columns="'+thumb_columns+'"' : '';
		    	mb_attachment_spacing = ( attachment_spacing ) ? ' spacing="'+attachment_spacing+'"' : '';
		    	mb_thumb_width = ( thumb_width ) ? ' thumb_width="'+thumb_width+'"' : '';
		    	mb_thumb_height = ( thumb_height ) ? ' thumb_height="'+thumb_height+'"' : '';
		    	break;
		    case 'slider':
		    	mb_gallery_width = ( gallery_width ) ? ' width="'+gallery_width+'"' : '';
		    	mb_gallery_height = ( gallery_height ) ? ' height="'+gallery_height+'"' : '';
		    	mb_gallery_timer = gallery_timer ? ' timer="true"' : '';
		    	mb_gallery_timer_speed = ( gallery_timer_speed ) ? ' timer_speed="'+gallery_timer_speed+'"' : '';
		    	break;
		    case 'list':
		    	mb_attachment_spacing = ( attachment_spacing ) ? ' spacing="'+attachment_spacing+'"' : '';
		    	mb_gallery_width = ( gallery_width ) ? ' width="'+gallery_width+'"' : '';
		    	mb_gallery_height = ( gallery_height ) ? ' height="'+gallery_height+'"' : '';
		    	break;  
	    }

	    window.send_to_editor('[mediablender id="'+gallery_id+'" name="'+gallery_name+'" type="'+gallery_type+'" data="'+data_position+'" navigation="'+nav_position+'"'+mb_gallery_title+mb_gallery_description+mb_attachment_titles+mb_attachment_descriptions+mb_attachment_comments+mb_thumb_columns+mb_thumb_width+mb_thumb_height+mb_attachment_spacing+mb_gallery_width+mb_gallery_height+mb_gallery_timer+mb_gallery_timer_speed+']');
	  }
	</script>
	
	<div id="mediablender_gallery_chooser" style="display:none;">
		<div class="wrap">
	    <div>
        <div style="padding:15px 15px 0 15px;">
        		<img style="float:left;margin-top:22px;margin-right:10px;" src="<?php echo MEDIABLENDER_IMAGES_URL; ?>/mediablender-icon-32.png" width="32" heigh="32" />
            <h3 style="color:#5A5A5A!important; font-family:Georgia,Times New Roman,Times,serif!important; font-size:1.8em!important; font-weight:normal!important;"><?php _e('Insert A Gallery', 'm4c'); ?></h3>
            <span><?php _e('Select a MediaBlender gallery to add it to your post or page.', 'm4c'); ?></span>
        </div>
        <div style="padding:15px 15px 0 15px;">
	        <select id="add_gallery_id">
	        	<option value=""><?php _e('Select a Gallery', 'm4c'); ?></option>
	        	<?php
	        	$args = array(
	        		'post_type' => 'mediablender',
	        		'numberposts' => -1,
	        		'orderby' => 'title',
	        		'order' => 'ASC'
	        	);
	        	$gallery_array = get_posts( $args );
	        	if( is_array($gallery_array) ) {
	        		foreach( $gallery_array as $gallery ) {
		        		echo '<option value="'.$gallery->ID.'">'.$gallery->post_title.'</option>';
	        		}
	        	}
	        	?>
	        </select>&nbsp;&nbsp;<a href="<?php echo get_admin_url( false, 'post-new.php?post_type=mediablender' )?>"><?php _e('Add gallery', 'm4c'); ?></a>
	        <br/>
	        <div style="padding:8px 0 0 0; font-size:11px; font-style:italic; color:#5A5A5A"><?php _e('Can\'t find your gallery? Make sure it is active.', 'm4c'); ?></div>
        </div>
        <div style="padding:15px 15px 0 15px;">
        
        	<p style="margin-bottom:0;"><strong><?php _e('Gallery Type', 'm4c'); ?></strong></p>
        	<p style="padding-top:0;">
	        	<input type="radio" class="gallery-type" value="lightbox" name="gallery_type" checked='checked' /> <label for="lightbox"><?php _e('Lightbox', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
	        	<input type="radio" class="gallery-type" value="slider" name="gallery_type" /> <label for="slider"><?php _e('Slider', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
	        	<input type="radio" class="gallery-type" value="list" name="gallery_type" /> <label for="list"><?php _e('List', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
        	</p>
		      
		      <div id="gallery-options">
		      
		      	<div class="gallery-option lightbox-option">
			      	<label for="thumb_width" style="display:inline-block;width:100px;"><strong><?php _e('Thumb Width', 'm4c'); ?></strong></label>
			      	<input style="width:50px;text-align:right;" type="text" id="thumb_width" value="120" /><span style="color:#2175A3;"> px</span>
		      	</div>
		      	
		      	<div class="gallery-option lightbox-option">
			      	<label for="thumb_height" style="display:inline-block;width:100px;"><strong><?php _e('Thumb Height', 'm4c'); ?></strong></label>
			      	<input style="width:50px;text-align:right;" type="text" id="thumb_height" value="120" /><span style="color:#2175A3;"> px</span> 
		      	</div>
		      	
		      	<div class="gallery-option lightbox-option">
			      	<label for="thumb_columns" style="display:inline-block;width:125px;"><strong><?php _e('Thumbnail columns', 'm4c'); ?></strong></label>
			      	<select id="thumb_columns">
			      		<option>1</option>
			      		<option>2</option>
			      		<option>3</option>
			      		<option>4</option>
			      		<option>5</option>
			      		<option selected="selected">6</option>
			      		<option>7</option>
			      		<option>8</option>
			      		<option>9</option>
			      		<option>10</option>
			      	</select>
		      	</div>
		      
		      	<div class="gallery-option lightbox-option list-option">
			      	<label for="attachment_spacing" style="display:inline-block;width:125px;"><strong><?php _e('Attachment Spacing', 'm4c'); ?></strong></label>
			      	<input style="width:50px;" type="text" id="attachment_spacing" value="10" /><span style="color:#2175A3;"> px</span>
		      	</div>
		      	
		      	<div class="gallery-option slider-option list-option">
			      	<label for="gallery_width" style="display:inline-block;width:100px;"><strong><?php _e('Gallery Width', 'm4c'); ?></strong></label>
			      	<input style="width:50px;text-align:right;" type="text" id="gallery_width" /><span style="color:#2175A3;"> px</span> <small style="font-style:italic;font-weight:bold;"><?php _e('( Leave blank to auto-size )', 'm4c'); ?></small>
		      	</div>
		      	
		      	<div class="gallery-option slider-option list-option">
			      	<label for="gallery_height" style="display:inline-block;width:100px;"><strong><?php _e('Gallery Height', 'm4c'); ?></strong></label>
			      	<input style="width:50px;text-align:right;" type="text" id="gallery_height" /><span style="color:#2175A3;"> px</span> <small style="font-style:italic;font-weight:bold;"><?php _e('( Leave blank to auto-size )', 'm4c'); ?></small>
		      	</div>
		      	
		      	<div class="gallery-option slider-option">
		      		<label for="gallery_timer" style="display:inline-block;width:100px;height:25px;line-height:25px;"><strong><?php _e('Enable Timer', 'm4c'); ?></strong></label>
		      		<input style="margin-top:3px;" type="checkbox" id="gallery_timer" />
		      	</div>
		      	
		      	<div class="gallery-option slider-option">
			      	<label for="gallery_timer_speed" style="display:inline-block;width:100px;"><strong><?php _e('Timer Speed', 'm4c'); ?></strong></label>
			      	<input style="width:50px;text-align:right;" type="text" id="gallery_timer_speed" value="7" /><span style="color:#2175A3;"> seconds</span> <small style="font-style:italic;font-weight:bold;"></small>
		      	</div>

		      </div>

        	<p style="margin-bottom:0;"><strong><?php _e('Gallery Options', 'm4c'); ?></strong></p>
        	<p style="padding-top:0;">
			      <input type="checkbox" id="display_gallery_title" /> <label for="display_gallery_title"><?php _e('Display gallery title', 'm4c'); ?></label> &nbsp;&nbsp;&nbsp;
			      <input type="checkbox" id="display_gallery_description" /> <label for="display_gallery_description"><?php _e('Display gallery description', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
        	</p>

        	<p style="margin-bottom:0;"><strong><?php _e('Attachment Options', 'm4c'); ?></strong></p>
        	<p style="padding-top:0;">
			      <input type="checkbox" id="display_attachment_titles" /> <label for="display_attachment_titles"><?php _e('Display attachments titles', 'm4c'); ?></label> &nbsp;&nbsp;&nbsp;
			      <input type="checkbox" id="display_attachment_descriptions" /> <label for="display_attachment_descriptions"><?php _e('Display attachment descriptions', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
			      <input type="checkbox" id="attachment_comments" /> <label for="attachment_comments"><?php _e('Attachment comments', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
        	</p>
        	
        	<p style="margin-bottom:0;"><strong><?php _e('Data Position', 'm4c'); ?></strong></p>
        	<p style="padding-top:0;">
	        	<input type="radio" class="data-position" value="sidebar" name="data_position" checked='checked' /> <label for="sidebar"><?php _e('Sidebar', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
	        	<span class="gallery-option slider-option list-option"><input type="radio" class="data-position" value="above" name="data_position" /> <label for="above"><?php _e('Above', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;</span>
	        	<span class="gallery-option slider-option list-option"><input type="radio" class="data-position" value="below" name="data_position" /> <label for="below"><?php _e('Below', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;</span>
	        	<input type="radio" class="data-position" value="overlay_top" name="data_position" /> <label for="overlay_top"><?php _e('Overlay Top', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
	        	<input type="radio" class="data-position" value="overlay_bottom" name="data_position" /> <label for="overlay_bottom"><?php _e('Overlay Bottom', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
        	</p>
        	
        	<div class="gallery-option slider-option lightbox-option">
	        	<p style="margin-bottom:0;"><strong><?php _e('Navigation Position', 'm4c'); ?></strong></p>
	        	<p style="padding-top:0;">
		        	<input type="radio" class="navigation-position" value="none" name="navigation_position" checked='checked' /> <label for="none"><?php _e('None', 'm4c'); ?></label><br/>
		        	<input type="radio" class="navigation-position" value="top-left" name="navigation_position" /> <label for="top-left"><?php _e('Top Left', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
		        	<input type="radio" class="navigation-position" value="top-center" name="navigation_position" /> <label for="top-center"><?php _e('Top Center', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
		        	<input type="radio" class="navigation-position" value="top-right" name="navigation_position" /> <label for="top-right"><?php _e('Top Right', 'm4c'); ?></label><br/>
		        	<input type="radio" class="navigation-position" value="bottom-left" name="navigation_position" /> <label for="bottom-left"><?php _e('Bottom Left', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
		        	<input type="radio" class="navigation-position" value="bottom-center" name="navigation_position" /> <label for="bottom-center"><?php _e('Bottom Center', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp;
		        	<input type="radio" class="navigation-position" value="bottom-right" name="navigation_position" /> <label for="bottom-right"><?php _e('Bottom Right', 'm4c'); ?></label>&nbsp;&nbsp;&nbsp; 	
	        	</p>
        	</div>
        	
        </div>
        <div style="padding:15px;">
          <input type="button" class="button-primary" value="<?php _e('Insert Gallery', 'm4c'); ?>" onclick="mediablender_insert_gallery();"/>&nbsp;&nbsp;&nbsp;
          <a class="button" style="color:#bbb;" href="#" onclick="tb_remove(); return false;"><?php _e('Cancel', 'm4c'); ?></a>
        </div>
	    </div>
		</div>
	</div>
	<?php
}




/**
 * Add the MediaBlender lightbox for the edit.php preview
 *
 * @since 1.0
 */
function mediablender_preview_link() {
	?>
	<script>
	jQuery( document ).ready( function() {
		jQuery( '.mediablender-gallery-preview' ).mediablender({
			security: '<?php echo wp_create_nonce( 'm4c_ajax_file_nonce' ); ?>',
			nav_buttons: 1
		});
	});
	</script>
	<?php
}




add_filter( 'manage_edit-mediablender_columns', 'mediablender_edit_columns' );
/**
 * Set custom columns for MedaiBlender edit screen
 *
 * @since 1.0
 */
function mediablender_edit_columns( $columns ){
	
	$columns = array(
		'cb' => '<input type="checkbox" />',
		'mediablender-thumb' => '',
		'title' => __('Title', 'm4c'),
		'mediablender-attachments' => __('Attachments', 'm4c'),
		'date' => __('Created', 'm4c')
	);
	return $columns;
}




add_action( 'manage_posts_custom_column',  'mediablender_custom_columns' );
/**
 * Display the custom columns
 *
 * @since 1.1
 */
function mediablender_custom_columns( $column ){
	
	global $post;
	$id = get_the_ID();
	$atts = get_post_meta( $id, '_mediablender_attachments', true );
	
	switch ( $column ) {
			
		case 'mediablender-attachments':
			echo count( $atts );
			break;
			
		case 'mediablender-thumb':
			if( is_array($atts) ) {
				foreach( $atts as $i => $att ) {
					if( $i == 0 ) {
						$img = get_m4c_attachment_image( $atts[0], 'mediablender-column-image' );
						echo '<a href="#" id="'.$att.'" class="mediablender-gallery-preview" rel="'.$id.'">'.$img.'<span class="mediablender-preview-icon"><span></a>';
					} else {
						echo '<a href="#" id="'.$att.'" class="mediablender-gallery-preview" style="display:none;" rel="'.$id.'"></a>';
					}
				}
			}
			
			break;	
	}
}




add_filter( 'attachment_fields_to_edit', 'mediablender_attachment_fields_to_edit', null, 2 );
/**
 * Add, remove and modify attachment fields
 *
 * @since 1.1
 */
function mediablender_attachment_fields_to_edit( $form_fields, $post ) {
	
	/**
	 * Custom fields for images
	 *
	 * @since 1.0
	 */
	if( substr($post->post_mime_type, 0, 5) == 'image' ){
		
		$image_link = get_post_meta( $post->ID, '_image_link', true );
		$image_link_target = get_post_meta( $post->ID, '_image_link_target', true );
		
		$form_fields["image_link"]["label"] = '<span class="mediablender-label">'.__('Link', 'mediablender').'</span>';  
		$form_fields["image_link"]["input"] = "html";  
		$form_fields["image_link"]["html"] = "<input type='text' class='text' name='attachments[{$post->ID}][image_link]' value='".$image_link."'>";
		
		$targets = ( $image_link_target == '_self' ) ? '<option selected="selected">_self</option>' : '<option>_self</option>';
		$targets .= ( $image_link_target == '_blank' ) ? '<option selected="selected">_blank</option>' : '<option>_blank</option>';
		$targets .= ( $image_link_target == '_parent' ) ? '<option selected="selected">_parent</option>' : '<option>_parent</option>';
		$targets .= ( $image_link_target == '_top' ) ? '<option selected="selected">_top</option>' : '<option>_top</option>';	
		
		$form_fields["image_link_target"]["label"] = '<span class="mediablender-label">'.__('Link Target', 'mediablender').'</span>';
		$form_fields["image_link_target"]["input"] = "html";  
		$form_fields["image_link_target"]["html"] = " 
		<select name='attachments[{$post->ID}][image_link_target]' id='attachments[{$post->ID}][image_link_target]'>{$targets}</select>"; 
	}
	    
  return $form_fields;
}




add_filter( 'attachment_fields_to_save', 'mediablender_attachment_fields_to_save', 10, 2 );
/**
 * Save the custom attachment fields
 *
 * @since 1.4.1
 */
function mediablender_attachment_fields_to_save( $post, $attachment ) {  
	
	if( isset($attachment['image_link']) ) {
		update_post_meta( $post['ID'], '_image_link', $attachment['image_link'] );
	}	
	if( isset($attachment['image_link_target']) ) {
		update_post_meta( $post['ID'], '_image_link_target', $attachment['image_link_target'] );
	}
        
  return $post;  
}  