<?php
/**
 * This is where we put all the functions that that pertain to the plugin
 * to media globally throughout the site.
 *
 * @category 			Plugins
 * @package  			MediaBlender
 * @author   			Metaphor Creations
 * @license: 			ThemeForest Licensing Terms
 * @license uri:	http://www.20script.ir
 * @link     			http://plugins.metaphorcreations.com/mediablender
 **/
 
 

 
/**
 * Add image sizes.
 *
 * @since 1.0.0
 */
if ( function_exists( 'add_image_size' ) ) { 

	// Create custom image sizes
	add_image_size( 'mediablender-comment-image', 35, 35, true );
	add_image_size( 'mediablender-column-image', 50, 50, true );
	add_image_size( 'mediablender', 1200 );
}




add_action( 'wp_enqueue_scripts', 'mediablender_scripts' );
/**
 * Add the necessary scripts to the font end.
 *
 * @since 1.1
 */
function mediablender_scripts() {
	
	// Add the stylesheet
	wp_register_style( 'mediablender', MEDIABLENDER_URL.'/css/mediablender.css', false, MEDIABLENDER_VERSION );
	wp_enqueue_style( 'mediablender' );
	
	// Add the jQuery cookie script
	wp_register_script( 'jquery-cookie', MEDIABLENDER_URL.'/js/jquery.cookie.js', array( 'jquery' ), METATOOLS_VERSION, true );
	wp_enqueue_script( 'jquery-cookie' );
	
	// Add jQuery easing
	wp_register_script( 'jquery-easing', MEDIABLENDER_URL.'/js/jquery.easing.js', array('jquery'), MEDIABLENDER_VERSION, true );
	wp_enqueue_script( 'jquery-easing' );
	
	// Add jQuery timers
	wp_register_script( 'jquery-timers', MEDIABLENDER_URL.'/js/jquery.timers-1.1.3.js', array('jquery'), MEDIABLENDER_VERSION, true );
	wp_enqueue_script( 'jquery-timers' );
	
	// Add the jQuery
	wp_register_script( 'mediablender', MEDIABLENDER_URL.'/js/mediablender.js', array('jquery', 'jquery-cookie'), MEDIABLENDER_VERSION, true );
	wp_enqueue_script( 'mediablender' );
	
	// Create navigation settings
	$nav_settings = array(
		'nav_before' => '',
		'nav_after'  => '',
		'nav_link_before' => '',
		'nav_link_after'  => '',
	);
	$nav_settings = apply_filters( 'mediablender_nav_settings', $nav_settings );
	
	wp_localize_script( 'mediablender', 'mediablender_vars', array(
			'cookie_hash' => COOKIEHASH,
			'comment_text' => __('Comments', 'm4c'),
			'comment_single' => __('Comment', 'm4c'),
			'nav_settings' => $nav_settings
		)
	);
}




add_action( 'wp_head', 'mediablender_header_scripts' );
/**
 * Add header scripts.
 *
 * @since 1.1
 */
function mediablender_header_scripts() { 
	$options = get_option( 'mediablender_settings' );
	if( $options ) {
		$opacity = intval( $options['overlay_opacity'] )/100;
		$sidebar_width = ( $options['sidebar_width'] == '' ) ? '300' : intval(sanitize_text_field($options['sidebar_width']));
		$custom_styles = esc_textarea( $options['custom_styles'] );
	  ?>
	  <style>
		.mediablender-overlay {
			<?php if($options['overlay_pattern']!='none'){ ?>background: url(<?php echo $options['overlay_pattern']; ?>);<?php } ?>
			opacity: <?php echo $opacity; ?>;
		}
		.mediablender-data {
			width: <?php echo $sidebar_width; ?>px;
		}
		.mediablender-data input[type="text"],
		.mediablender-data textarea {
			width: <?php echo ( intval($sidebar_width)-60 ); ?>px;
		}
		<?php echo $custom_styles; ?>
		</style>
		<?php
	}
}




add_action( 'wp_footer', 'mediablender_footer_scripts' );
/**
 * Add footer scripts.
 *
 * @since 1.0
 */
function mediablender_footer_scripts() { 
	$options = get_option( 'mediablender_settings' );
  ?>
  <script>
	jQuery( document ).ready( function() {
		jQuery( '.mediablender-lightbox-link' ).mediablender({
			type: 'lightbox',
			security: '<?php echo wp_create_nonce( 'm4c_ajax_file_nonce' ); ?>',
			<?php if( $options ) { ?>
			sidebar_position: '<?php echo $options['sidebar_position']; ?>',
			sidebar_width: '<?php echo ( $options['sidebar_width'] == '' ) ? '300' : intval( sanitize_text_field($options['sidebar_width'])); ?>',
			autohide_info: '<?php echo isset($options['autohide_info']); ?>',
			autohide_nav: '<?php echo isset($options['autohide_nav']); ?>',
			nav_buttons: '<?php echo isset($options['nav_buttons']); ?>'
			<?php } ?>
		});
		jQuery( '.mediablender-slider' ).mediablender({
			type: 'slider',
			security: '<?php echo wp_create_nonce( 'm4c_ajax_file_nonce' ); ?>',
			<?php if( $options ) { ?>
			sidebar_position: '<?php echo $options['sidebar_position']; ?>',
			sidebar_width: '<?php echo ( $options['sidebar_width'] == '' ) ? '300' : intval( sanitize_text_field($options['sidebar_width'])); ?>',
			autohide_info: '<?php echo isset($options['autohide_info']); ?>',
			autohide_nav: '<?php echo isset($options['autohide_nav']); ?>',
			nav_overlay: '<?php echo isset($options['nav_overlay']); ?>',
			nav_buttons: '<?php echo isset($options['nav_buttons']); ?>'
			<?php } ?>
		});
		jQuery( '.mediablender-list-item' ).mediablender({
			type: 'list',
			security: '<?php echo wp_create_nonce( 'm4c_ajax_file_nonce' ); ?>',
			<?php if( $options ) { ?>
			sidebar_position: '<?php echo $options['sidebar_position']; ?>',
			sidebar_width: '<?php echo ( $options['sidebar_width'] == '' ) ? '300' : intval( sanitize_text_field($options['sidebar_width'])); ?>',
			autohide_info: '<?php echo isset($options['autohide_info']); ?>'
			<?php } ?>
		});
	});
	</script>
	<?php
}




add_filter( 'm4c_default_audio_image_src', 'mediablender_default_media_image_src' );
add_filter( 'm4c_default_video_image_src', 'mediablender_default_media_image_src' );
/**
 * Replace the default video and audio images
 *
 * @since 1.0
 */
function mediablender_default_media_image_src( $src ) {
	return MEDIABLENDER_IMAGES_URL.'/defaults/default-media.jpg';
}




add_action( 'wp_ajax_mediablender_structure', 'mediablender_structure' );
add_action( 'wp_ajax_nopriv_mediablender_structure', 'mediablender_structure' );
/**
 * Add the jQuery ajax call to get & setup the attachment.
 *
 * @since 1.0
 */
function mediablender_structure() {
	
	// Get access to the database
	global $wpdb;
	
	$wpurl = get_bloginfo( 'wpurl' );
	$url = get_bloginfo( 'url' );
	if( $wpurl == $url ) {
		// Check the nonce
		check_ajax_referer( 'm4c_ajax_file_nonce', 'security' );
	}
	
	// Get variables
	$att_id  = $_POST['att_id'];
	$type = $_POST['type'];
	$title = $_POST['title'];
	$description = $_POST['description'];	
	$comments = $_POST['comments'];
	$width = ( $_POST['width'] != 0 ) ? $_POST['width'] : false;
	$height = ( $_POST['height'] != 0 ) ? $_POST['height'] : false;

	// Get the post
	$att = get_post( $att_id );
	
	query_posts( array( 'attachment_id' => $att_id ) );
	if ( have_posts() ) {
		while( have_posts() ) {
			the_post();
			
			$attachment;
			$mime_type = get_post_mime_type();
			$dimensions = ( $height && $type != 'lightbox' ) ? array( $width, $height ) : array( $width );
	
			switch ( $mime_type ) {
				case 'image/jpeg':
					$attachment = wp_get_attachment_image( $att_id, 'mediablender' );
					break;
					
				case 'image/png':
					$attachment = wp_get_attachment_image( $att_id, 'mediablender' );
					break;

				case 'audio/mpeg':
					$attachment = get_m4c_audio( $att_id, array($width) );
					break;
		
				case 'video/mp4':
					$attachment = get_m4c_video( $att_id, array($width) );
					break;
					
				case 'video/m4v':
					$attachment = get_m4c_video( $att_id, array($width) );
					break;
				
				case 'vimeo':
				
					// Get the vimeo iframe
					$custom = get_m4c_image_size( 'mediablender' );
					$args = array(
						'att_id' => $att_id,
						'width' => $custom['width'],
						'height' => $custom['height'],
						'class'=> 'mediablender-attachment-video'
					);
					$attachment = get_m4c_vimeo( $args );
					break;
				
				case 'youtube':
					// Get the youtube iframe
					$custom = get_m4c_image_size( 'mediablender' );
					$args = array(
						'att_id' => $att_id,
						'width' => $custom['width'],
						'height' => $custom['height'],
						'class'=> 'mediablender-attachment-video'
					);
					$attachment = get_m4c_youtube( $args );
					break;
			}			
			?>
			<div class="mediablender-container clearfix">
				<div class="mediablender-attachment-container clearfix">
					<div class="mediablender-attachment"><?php echo $attachment; ?></div>
				</div>
				<div class="mediablender-data">
					<div class="mediablender-data-container">
						<?php if( $title=='true' ) { ?>
						<h3 class="mediablender-entry-title"><?php the_title(); ?></h3>
						<?php } ?>
						<div class="mediablender-sidebar-scroll-container">
							<div class="mediablender-scroll-shadow-top"></div>
							<div class="mediablender-sidebar-scroll">
								
								<?php if( $comments=='true' ) { ?>
								<p class="mediablender-comment-count"><a href="#"><?php printf( _n( '1 Comment', '%1$s Comments', get_comments_number() ), number_format_i18n( get_comments_number() ) ); ?></a></p>
								<?php } ?>
								
								<?php
								if( $description=='true' ) {
									if( isset( $att->post_content ) ) {
										if( $att->post_content != '' ) {?>
											<p class="mediablender-entry-description"><?php echo $att->post_content; ?></p>
									<?php
										}
									}
								}
								?>
								<?php if( $comments=='true' ) { ?>
								
								<div class="mediablender-comments">		
									<div class="mediablender-commentscontainer">
										<ol class="mediablender-commentlist">
											<?php
											$att_comments = get_comments( array(
												'post_id' => $att_id,
												'order' => 'ASC',
												'status' => 'approve'
											));
											foreach( $att_comments as $comment ) {
												mediablender_comment_structure( $comment );
											}
											?>
										</ol>
									</div>
										
								</div><!-- #comments -->

								<?php } ?>
							</div><!-- mediablender-sidebar-scroll -->
						</div><!-- .mediablender-sidebar-scroll-container -->
	
						<?php if( $comments=='true' ) { ?>
							<div class="mediablender-commentform-container">
								<img class="m4c-loading-gif" src="<?php echo MEDIABLENDER_IMAGES_URL; ?>/loading.gif" width="16" height="16" />
								<?php
								/**
								 * Create the inputs for the form.
								 */
								$author = '<div class="control-group comment-form-author"><div class="controls"><input name="author" type="text" value="" aria-required="true" placeholder="'.__('Name', 'm4c').' *" /></div></div>';
								
								$email = '<div class="control-group comment-form-email"><div class="controls"><input name="email" type="text" value="" size="30" aria-required="true" placeholder="'.__('Email', 'm4c').' *" /></div></div>';
								
								$url = '<div class="control-group comment-form-url"><div class="controls"><input  name="url" type="text" value="" size="30" placeholder="'.__('Website', 'm4c').'" /></div></div>';
								
								$comment_field = '<div class="control-group comment-form-comment"><div class="controls"><textarea name="comment" cols="45" rows="1" aria-required="true" placeholder="'.__('Add a comment...', 'm4c').'"></textarea></div></div>';
								
								// Set the fields
								$fields =  array(
									'author' => $author,
									'email' => $email,
									'url' => $url
								);
								
								// Set the arguments
								$args = array (
									'id_form' => '',
									'fields' => $fields,
									'comment_field' => $comment_field,
									'class_submit' => 'btn',
									'label_submit' => '',
									'title_reply' => false,
									'comment_notes_before' => false,
									'comment_notes_after' => false,
									'cancel_reply_link' => 'Cancel',
									'logged_in_as' => ''
								);
								
								comment_form( $args, get_the_ID() );
								?>
								<a href="#" class="mediablender-collapse-button"></a>
							</div>
					<?php } ?>
					</div>
				</div>
			</div>
		<?php
		}
	}
	
	die(); // this is required to return a proper result
}




/**
 * Setup the comments return
 *
 * @since 1.0
 */
if ( !function_exists('mediablender_comment') ) :

function mediablender_comment( $comment, $args, $depth ) {
	
	$GLOBALS['comment'] = $comment;
	mediablender_comment_structure( $comment );
}
endif;




/*
 * Display a comment.
 *
 * @since 1.0
 */
function mediablender_comment_structure( $comment ) {
	
	// Get the default avatar
	$default_avatar = false;
	if( function_exists('get_maven_default_avatar_src') ) {
		$default_avatar = get_maven_default_avatar_src( 'mediablender-comment-image' );
	}
	$todays_date = date(get_option('date_format'),current_time('timestamp'));
	$date_format = ( $todays_date == get_comment_date(get_option('date_format'), $comment->comment_ID) ) ? get_option('date_format').' '.get_option('time_format') : get_option('date_format');
	?>
	<li id="li-comment-<?php echo $comment->comment_ID; ?>" <?php if ($comment->comment_approved!='1'){echo ' class="mediablender-comment-onhold"';}?>>
	  <table id="comment-<?php echo $comment->comment_ID; ?>" class="comment-table">
			<tr> 
	      <td class="mediablender-comment-avatar">
				<?php echo get_avatar( $comment->user_id, 35, $default_avatar[0] ); ?>
	      </td><!-- .comment-avatar -->
	      
	      <?php if ( $comment->comment_approved == '1' ) : ?>
	      <td class="mediablender-comment-data">
					<p class="mediablender-comment-header"><span class="mediablender-comment-author"><?php echo get_comment_author_link($comment->comment_ID); ?></span> <span class="mediablender-comment-date"><?php echo get_comment_date($date_format, $comment->comment_ID); ?></span></p>
					<?php comment_text($comment->comment_ID); ?>
        </td><!-- .comment-meta -->
	      <?php else: ?>
        <td colspan="2" class="mediablender-comment-data mediablender-comment-onhold">
	        <p class="mediablender-comment-header"><span class="mediablender-comment-author"><?php echo get_comment_author_link($comment->comment_ID); ?></span> <span class="mediablender-comment-date"><?php echo get_comment_date($date_format, $comment->comment_ID); ?></span></p>
					<p class="mediablender-comment-awaiting-moderation"><?php _e('* Waiting for approval.', 'm4c'); ?></p>
					<?php comment_text($comment->comment_ID); ?>
	      </td><!-- #comment-data -->
        <?php endif; ?>              
			</tr>   
    </table><!-- #comment-##  -->
	</li>
  <?php
}




add_action( 'comment_post', 'mediablender_ajax_comment', 20, 2 );
/*
 * Intercept the comment to work with ajax.
 *
 * @since 1.0
 */
function mediablender_ajax_comment( $comment, $status ){

	if( !empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest'){
		//If AJAX Request Then
		switch( $status ){
			case '0':
				$commentdata =& get_comment( $comment );
				$post =& get_post( $commentdata->comment_post_ID );
				wp_notify_moderator($comment);
				mediablender_comment_structure( $commentdata );
				break;
			
			case '1':
				$commentdata =& get_comment( $comment );
				$post =& get_post( $commentdata->comment_post_ID );
				wp_notify_postauthor( $comment, $commentdata->comment_type );
				mediablender_comment_structure( $commentdata );
				break;
				
			default:
				echo 'error';
		}
		exit;
	}
}




add_shortcode( 'mediablender', 'mediablender_shortcode' );
/**
 * Add the MediaBlender gallery.
 *
 * @since 1.1
 */
function mediablender_shortcode( $atts, $content = null ) {
	extract( shortcode_atts( array(
		'id' => '',
		'name' => '',
		'type' => '',
		'data' => '',
		'navigation' => '',
		'width' => '',
		'height' => '',
		'thumb_width' => '120',
		'thumb_height' => '120',
		'fill' => 'true',
		'title' => 'true',
		'description' => 'true',
		'att_titles' => 'true',
		'att_descriptions' => 'true',
		'att_comments' => 'true',
		'timer' => false,
		'timer_speed' => 7,
		'columns' => 6,
		'spacing' => 0
	), $atts ) );

	$gallery = get_post( $id );
	
	$att_ids = get_post_meta( $id, '_mediablender_attachments', true );
	
	$output = '<div class="mediablender-gallery mediablender-'.$type.' mediablender-'.$gallery->post_name.'">';

	$output .= '<div class="mediablender-settings">';
		$output .= ( $data == '' ) ? '' : '<input type="hidden" name="data_position" value="'.$data.'" />';
		$output .= ( $navigation == '' ) ? '' : '<input type="hidden" name="nav_position" value="'.$navigation.'" />';
		$output .= ( $width == '' ) ? '' : '<input type="hidden" name="width" value="'.intval(sanitize_text_field($width)).'" />';
		$output .= ( $height == '' ) ? '' : '<input type="hidden" name="height" value="'.intval(sanitize_text_field($height)).'" />';
		$output .= ( $att_titles == 'true' ) ? '<input type="hidden" name="show_titles" value="true" />' : '<input type="hidden" name="show_titles" value="false" />';
		$output .= ( $att_descriptions == 'true' ) ? '<input type="hidden" name="show_descriptions" value="true" />' : '<input type="hidden" name="show_descriptions" value="false" />';
		$output .= ( $att_comments == 'true' ) ? '<input type="hidden" name="show_comments" value="true" />' : '<input type="hidden" name="show_comments" value="false" />';
		$output .= ( $att_comments == 'true' ) ? '<input type="hidden" name="show_comments" value="true" />' : '<input type="hidden" name="show_comments" value="false" />';
		$output .= ( $timer == 'true' ) ? '<input type="hidden" name="timer" value="true" />' : '<input type="hidden" name="timer" value="false" />';
		$output .= ( $timer_speed == '' ) ? '' : '<input type="hidden" name="timer_speed" value="'.floatval(sanitize_text_field($timer_speed)).'" />';
	$output .= '</div>';
	
	if( $title == 'true' ) {
		$output .= '<h3 class="mediablender-title">'.$name.'</h3>';
	}
	if( $description == 'true' ) {
		$desc = get_post_meta( $id, '_mediablender_description', true );
		$output .= '<div class="mediablender-description">'.wpautop(esc_textarea($desc)).'</div>';
	}	
	if( $type != 'list' ) {
		$style = '';
		if( $type == 'slider' ) {
			$w_style = ( $width == '' ) ? '' : 'width:'.$width.'px;';
			$h_style = ( $height == '' ) ? '' : 'height:'.$height.'px;';
			$style = ( $w_style == '' && $h_style == '' ) ? '' : 'style="'.$w_style.$h_style.'"';
		}
		$output .= '<div class="mediablender-container clearfix"'.$style.'>';
	}
	
	switch( $type ) {
		case 'lightbox':
			$output .= mediablender_shortcode_lightbox( $id, $att_ids, $thumb_width, $thumb_height, $columns, intval(sanitize_text_field($spacing)) );
			break;
		case 'slider':
			$output .= mediablender_shortcode_slider( $att_ids, intval(sanitize_text_field($width)), intval(sanitize_text_field($height)) );
			break;
		case 'list':
			$output .= mediablender_shortcode_list( $att_ids, $spacing );
			break;
	}
	
	if( $type != 'list' ) {
		$output .= '</div>';
	}
	
	$output .= '</div>';
	
	return $output;	
}




/**
 * Create the display for lightbox galleries.
 *
 * @since 1.2
 */
function mediablender_shortcode_lightbox( $id, $att_ids, $thumb_width, $thumb_height, $columns, $spacing ) {
	$options = get_option( 'mediablender_settings' );
	$icon = false;
	
	$display_icon = false;
	
	if( $options ) {
		$display_icon = ( isset($options['thumbnail_icons']) ) ? true : false;
	}	

	$output = '';
	if( is_array($att_ids) ) {
		foreach( $att_ids as $i => $att_id ) {
			
			$style = ( ($i+1)%$columns==0 ) ? 'margin:0 0 '.$spacing.'px 0' : 'margin:0 '.$spacing.'px '.$spacing.'px 0';
			
			$output .= '<div class="mediablender-lightbox-item" style="'.$style.'" class="mediablender-lightbox-item">';
			
			$link = esc_url( get_post_meta($att_id, '_image_link', true) );
			$target = get_post_meta($att_id, '_image_link_target', true);
			if( $link != '' ) {
				$output .= '<a id="'.$att_id.'" href="'.$link.'" target="'.$target.'">';
			} else {
				$output .= '<a id="'.$att_id.'" href="#" rel="gallery-'.$id.'" class="mediablender-lightbox-link">';
			}
			
			if( $thumb_width=='120' && $thumb_height=='120' ) {
				$thumb = get_m4c_attachment_image( $att_id, 'm4c-gallery-thumb' );
			} else {
				$mime = get_post_mime_type( $att_id );
				if( $mime=='youtube' || $mime=='vimeo' ) {
					$thumb = get_m4c_attachment_image( $att_id, array($thumb_width, $thumb_height) );
				} else {
					$src = get_m4c_attachment_image_src( $att_id, 'large' );
					$thumb = get_m4c_timthumb_image( $src[0], array($thumb_width, $thumb_height) );
				}
			}
			
			if( $display_icon ) {
				if( $attachment = get_post($att_id) ) {
					$mime = $attachment->post_mime_type;
					switch ( $mime ) {
						case 'image/jpeg':
							$thumb .= '<span class="mediablender-mime-type mediablender-mime-type-image"></span>';
							break;
							
						case 'image/png':
							$thumb .= '<span class="mediablender-mime-type mediablender-mime-type-image"></span>';
							break;
						
						case 'audio/mpeg':
							$thumb .= '<span class="mediablender-mime-type mediablender-mime-type-audio"></span>';
							break;
				
						case 'video/mp4':
							$thumb .= '<span class="mediablender-mime-type mediablender-mime-type-video"></span>';
							break;
							
						case 'video/m4v':
							$thumb .= '<span class="mediablender-mime-type mediablender-mime-type-video"></span>';
							break;
						
						case 'vimeo':
							$thumb .= '<span class="mediablender-mime-type mediablender-mime-type-vimeo"></span>';
							break;
						
						case 'youtube':
							$thumb .= '<span class="mediablender-mime-type mediablender-mime-type-youtube"></span>';
							break;
					}
				}
			}
			
			$thumb = apply_filters( 'mediablender_thumb', $thumb, $att_id );
			
			$output .= $thumb;

			$output .= '</a>';
			
			$output .= '</div>';
		}
	}
	return $output;
}




/**
 * Create the display for slider galleries.
 *
 * @since 1.1
 */
function mediablender_shortcode_slider( $att_ids, $width, $height ) {
	$output = '';
	if( is_array($att_ids) ) {
		foreach( $att_ids as $i => $att_id ) {
			$link = esc_url( get_post_meta($att_id, '_image_link', true) );
			$target = get_post_meta($att_id, '_image_link_target', true);
			if( $link != '' ) {
				$output .= '<a href="'.$link.'" target="'.$target.'" id="'.$att_id.'"></a>';
			} else {
				$output .= '<a href="#" id="'.$att_id.'"></a>';
			}
		}
	}
	return $output;
}




/**
 * Create the display for list galleries.
 *
 * @since 1.1
 */
function mediablender_shortcode_list( $att_ids, $spacing ) {
	$output = '';
	if( is_array($att_ids) ) {
		foreach( $att_ids as $i => $att_id ) {
			$output .= '<div class="clearfix" style="margin-bottom:'.$spacing.'px;"><div class="mediablender-list-item clearfix" id="'.$att_id.'"></div></div>';
		}
	}
	return $output;
}