<?php
/**
 * This is where we put the options code for the plugin
 * to the content editor within the admin
 *
 * @category 			Plugins
 * @package  			MediaBlender
 * @author   			Metaphor Creations
 * @license: 			ThemeForest Licensing Terms
 * @license uri:	http://20script.ir
 * @link     			http://plugins.metaphorcreations.com/mediablender
 **/
 
 


add_action( 'admin_menu', 'm4c_mediablender_settings' );
/**
 * Add a menu page to display options and posttype.
 *
 * @since 1.0
 */
function m4c_mediablender_settings() {

	add_submenu_page(
		'edit.php?post_type=mediablender',				// The ID of the top-level menu page to which this submenu item belongs
		'Settings',												// The value used to populate the browser's title bar when the menu page is active
		'Settings',												// The label of this submenu item displayed in the menu
		'administrator',								// What roles are able to access this submenu item
		'mediablender_settings_menu',	// The ID used to represent this submenu item
		'mediablender_plugin_menu_display'				// The callback function used to render the options for this submenu item
	);
}




/**
 * Renders a simple page to display for the theme menu defined above.
 *
 * @since 1.0
 */
function mediablender_plugin_menu_display() {
	?>
	<div class="wrap">
	
		<div id="icon-mediablender" class="icon32"></div>
		<h2>MediaBlender Settings</h2>
		<?php settings_errors(); ?>

		<form method="post" action="options.php">
			<?php
	
				settings_fields( 'mediablender_settings' );
				do_settings_sections( 'mediablender_settings' );
	
				submit_button();
			?>
		</form>

	</div><!-- /.wrap -->
	<?php
}




add_action( 'admin_init', 'm4c_initialize_mediablender_settings' );
/**
 * Initializes the options page.
 *
 * @since 1.0
 */ 
function m4c_initialize_mediablender_settings() {

	// If the theme options don't exist, create them.
	if( false == get_option( 'mediablender_settings' ) ) {	
		add_option( 'mediablender_settings' );
	}
	
	/* Register the general options */
	add_settings_section(
		'mediablender_settings_section',						// ID used to identify this section and with which to register options
		__('General Options', 'm4c'),								// Title to be displayed on the administration page
		'mediablender_settings_section_callback',		// Callback used to render the description of the section
		'mediablender_settings'											// Page on which to add this section of options
	);
	
	// Sidebar Position
	add_settings_field(	
		'sidebar_position',												// ID used to identify the field throughout the theme
		__('Sidebar Position', 'm4c'),						// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'sidebar_position',
			'id' => 'mediablender_settings[sidebar_position]',
			'type' => 'radio',
			'options' => array(
				'left' => __('Left', 'm4c'),
				'right' => __('Right', 'm4c')
			),
			'description' => __('Choose to align the sidebar to the left or right.', 'm4c'),
			'default' => 'right',
			'display' => 'inline'
		)
	);
	
	// Sidebar Width
	add_settings_field(	
		'sidebar_width',													// ID used to identify the field throughout the theme
		__('Sidebar Width', 'm4c'),								// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'sidebar_width',
			'id' => 'mediablender_settings[sidebar_width]',
			'type' => 'text',
			'description' => __('Set the width of the sidebar. *Must be in pixels.', 'm4c'),
			'default' => '300',
			'after' => __(' px', 'm4c'),
			'text_align' => 'right',
			'size' => 10
		)
	);
	
	// Autohide Info
	add_settings_field(	
		'autohide_info',													// ID used to identify the field throughout the theme
		__('Auto-hide Info', 'm4c'),							// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'autohide_info',
			'id' => 'mediablender_settings[autohide_info]',
			'type' => 'checkbox',
			'label' => __('Show/hide the info on mouse over/mouse out', 'm4c'),
			'description' => __('* This will not effect info shown in the sidebar.', 'm4c')
		)
	);
	
	// Navigation overlay
	add_settings_field(	
		'nav_overlay',														// ID used to identify the field throughout the theme
		__('Navigation Overlay', 'm4c'),					// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'nav_overlay',
			'id' => 'mediablender_settings[nav_overlay]',
			'type' => 'checkbox',
			'label' => __('Position the navigation over the attachments', 'm4c'),
			'description' => __('* When using a lightbox, the navigation will always overlay the attachments.', 'm4c')
		)
	);
	
	// Use nav buttons
	add_settings_field(	
		'nav_buttons',														// ID used to identify the field throughout the theme
		__('Use Navigation Buttons', 'm4c'),			// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'nav_buttons',
			'id' => 'mediablender_settings[nav_buttons]',
			'type' => 'checkbox',
			'label' => __('Use buttons instead of numbers', 'm4c')
		)
	);
	
	// Autohide Nav
	add_settings_field(	
		'autohide_nav',														// ID used to identify the field throughout the theme
		__('Auto-hide Nav', 'm4c'),								// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'autohide_nav',
			'id' => 'mediablender_settings[autohide_nav]',
			'type' => 'checkbox',
			'label' => __('Show/hide the navigation on mouse over/mouse out', 'm4c'),
			'description' => __('* This only effects the overlayed navigation.', 'm4c')
		)
	);

	// Pattern Overlay
	add_settings_field(	
		'overlay_pattern',												// ID used to identify the field throughout the theme
		__('Lightbox Overlay Pattern', 'm4c'),		// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'overlay_pattern',
			'id' => 'mediablender_settings[overlay_pattern]',
			'type' => 'select',
			'description' => __('Select the overlay to use for the lightbox.', 'm4c'),
			'options' => get_m4c_patterns()
		)
	);

	// Overlay Opacity
	add_settings_field(	
		'overlay_opacity',												// ID used to identify the field throughout the theme
		__('Lightbox Overlay Opacity', 'm4c'),		// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'overlay_opacity',
			'id' => 'mediablender_settings[overlay_opacity]',
			'type' => 'number',
			'description' => __('Set the overlay opacity.', 'm4c'),
			'after' => ' 0-100'
		)
	);
	
	// Thumbnail Icons
	add_settings_field(	
		'thumbnail_icons',												// ID used to identify the field throughout the theme
		__('Thumbnail Icons', 'm4c'),							// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'thumbnail_icons',
			'id' => 'mediablender_settings[thumbnail_icons]',
			'type' => 'checkbox',
			'label' => __('Display file type icons on the thumbnails', 'm4c'),
			'description' => __('* This is only used with lightbox galleries.', 'm4c')
		)
	);
	
	// Custom Style
	add_settings_field(	
		'custom_styles',													// ID used to identify the field throughout the theme
		__('Custom Styles', 'm4c'),								// The label to the left of the option interface element
		'mediablender_settings_callback',									// The name of the function responsible for rendering the option interface
		'mediablender_settings',									// The page on which this option will be displayed
		'mediablender_settings_section',					// The name of the section to which this field belongs
		array(
			'option' => 'mediablender_settings',
			'option_id' => 'custom_styles',
			'id' => 'mediablender_settings[custom_styles]',
			'type' => 'textarea',
			'description' => __('Add custom styles to the galleries. This may be needed to override inherited styles from your theme.', 'm4c'),
			'cols' => 80,
			'rows' => 10
		)
	);
	
	// Register the fields with WordPress
	register_setting( 'mediablender_settings', 'mediablender_settings' );
}




/**
 * The callback function for the settings sections.
 *
 * @since 1.0
 */ 
function mediablender_settings_section_callback() {
	echo '<p>'.__('Set the global options for your MediaBlender galleries.', 'm4c').'</p>';
}





/**
 * The custom field callback.
 * This is used for the theme framework and all other M4C plugins.
 *
 * @since 1.0
 */ 
function mediablender_settings_callback( $args ) {
	
	// First, we read the options collection
	if( isset($args['option']) ) {
		$options = get_option( $args['option'] );
		$value = isset( $options[$args['option_id']] ) ? $options[$args['option_id']] : '';
	} else {
		$value = get_option( $args['id'] );
	}	
	if( $value == '' && isset($args['default']) ) {
		$value = $args['default'];
	}
	if( isset($args['type']) ) {
	
		echo '<div class="mediablender-metaboxer-field mediablender-metaboxer-'.$args['type'].'">';
		
		// Call the function to display the field
		if ( function_exists('mediablender_metaboxer_'.$args['type']) ) {
			call_user_func( 'mediablender_metaboxer_'.$args['type'], $args, $value );
		}
		
		echo '<div>';
	}
	
	// Add a descriptions
	if( isset($args['description']) ) {
		echo '<span class="description"><small>'.$args['description'].'</small></span>';
	}
}
