<?php
/*
Plugin Name: MediaBlender
Description: Powerful multimedia gallery plugin with three display options. Easily create multiple galleries and insert into site with a built-in shortcode generator. Create galleries with photos, audio, video, Youtube, and Vimeo.
Version: 1.4.3
Author: Metaphor Creations
Author URI: http://www.20script.ir
License: ThemeForest Licensing Terms
License URI:	http://20script.ir
*/

if( !function_exists('mediablender_init') ) {

	/** Define Constants */
	define ( 'MEDIABLENDER_VERSION', '1.4.3' );
	define ( 'MEDIABLENDER_DIR', plugin_dir_path(__FILE__) );
	define ( 'MEDIABLENDER_IMAGES_DIR', MEDIABLENDER_DIR.'images' );
	
	define ( 'MEDIABLENDER_URL', plugins_url().'/mediablender' );
	define ( 'MEDIABLENDER_IMAGES_URL', MEDIABLENDER_URL.'/images' );
	
	
	/** Add theme support */
	add_theme_support( 'mediablender' );
	add_theme_support( 'm4c_default_media_images' );
	
	
	add_action( 'plugins_loaded', 'mediablender_init' );
	/**
	 * Make sure other plugins are loaded before initializing.
	 *
	 * @since 1.0
	 */
	function mediablender_init() {
		
		/** Load Admin */
		if ( is_admin() ) {
			
			// Load Metaboxer
			require_once( MEDIABLENDER_DIR.'metaboxer/metaboxer.php' );
			require_once( MEDIABLENDER_DIR.'metaboxer/metaboxer-class.php' );
			add_action( 'admin_enqueue_scripts', 'mtphr_mediablender_metaboxer_scripts' );
		
			require_once( MEDIABLENDER_DIR.'mediablender-options.php' );
			require_once( MEDIABLENDER_DIR.'mediablender-admin.php' );
		}
		
		/** Load Functions */
		require_once( MEDIABLENDER_DIR.'mediablender-functions.php' );
		require_once( MEDIABLENDER_DIR.'metatools/metatools.php' );
	}
}




/**
 * Load the metaboxer scripts
 *
 * @since 1.4
 */
function mtphr_mediablender_metaboxer_scripts() {
	
	// Load the style sheet
	wp_register_style( 'mediablender-metaboxer', MEDIABLENDER_URL.'/metaboxer/metaboxer.css', array( 'colors', 'thickbox', 'farbtastic' ), MEDIABLENDER_VERSION );
	wp_enqueue_style( 'mediablender-metaboxer' );

	// Load the jQuery
	wp_register_script( 'mediablender-metaboxer', MEDIABLENDER_URL.'/metaboxer/metaboxer.js', array('jquery','media-upload','thickbox','jquery-ui-core','jquery-ui-sortable','jquery-ui-datepicker', 'jquery-ui-slider', 'farbtastic'), MEDIABLENDER_VERSION, true );
	wp_enqueue_script( 'mediablender-metaboxer' );
}




/************************************
* Software Update Code
*************************************/
define ( 'MEDIABLENDER_SL_STORE_URL', 'http://metaphorcreations.com' );
define ( 'MEDIABLENDER_SL_ITEM_NAME', 'MediaBlender' );
define ( 'MEDIABLENDER_SL_LICENSE_KEY', 'e07561d83b6c36abb3e92a2b7d8e40ff' );

if( !class_exists( 'EDD_SL_Plugin_Updater' ) ) {
	// load our custom updater
	include( dirname( __FILE__ ) . '/EDD_SL_Plugin_Updater.php' );
}

// setup the updater
$edd_updater = new EDD_SL_Plugin_Updater( MEDIABLENDER_SL_STORE_URL, __FILE__, array( 
		'version' 	=> '1.4.3', 													// current version number
		'license' 	=> MEDIABLENDER_SL_LICENSE_KEY, 		// license key (used get_option above to retrieve from DB)
		'item_name' => MEDIABLENDER_SL_ITEM_NAME, 			// name of this plugin
		'author' 	=> 'Metaphor Creations'  							// author of this plugin
	)
);

// activate the license
function mediablender_activate_license() {
	
	if( !get_option('mediablender_license_key') ) {

		// data to send in our API request
		$api_params = array( 
			'edd_action'=> 'activate_license', 
			'license' 	=> MEDIABLENDER_SL_LICENSE_KEY, 
			'item_name' => urlencode( MEDIABLENDER_SL_ITEM_NAME ) // the name of our product in EDD
		);
		
		// Call the custom API.
		$response = wp_remote_get( add_query_arg( $api_params, MEDIABLENDER_SL_STORE_URL ) );

		// make sure the response came back okay
		if ( is_wp_error( $response ) )
			return false;
			
		// Set the license option
		add_option( 'mediablender_license_key', MEDIABLENDER_SL_LICENSE_KEY );

		// decode the license data
		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// $license_data->license will be either "active" or "inactive"
		if( get_option('mediablender_license_status') ) {
			update_option( 'mediablender_license_status', $license_data->license );
		} else {
			add_option( 'mediablender_license_status', $license_data->license );	
		}
	}
}
add_action('admin_init', 'mediablender_activate_license');


